@@ -2,7 +2,7 @@
  *
  * Interface to block cryptos and hash functions
  *
- * $Id: abstract_crypto.h,v 1.34 2000/11/26 23:25:46 nisse Exp $ */
+ * $Id: abstract_crypto.h,v 1.36 2001/04/26 04:39:55 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -218,6 +218,7 @@ hash_string(struct hash_algorithm *a,
 	    struct lsh_string *in,
 	    int free);
 
+/* Used only by the testsuite */
 struct lsh_string *
 mac_string(struct mac_algorithm *a,
 	   struct lsh_string *key,
@@ -227,17 +228,17 @@ mac_string(struct mac_algorithm *a,
 
 struct lsh_string *
 crypt_string(struct crypto_instance *c,
-	     struct lsh_string *in,
+	     const struct lsh_string *in,
 	     int free);
 
 struct lsh_string *
 crypt_string_pad(struct crypto_instance *c,
-		 struct lsh_string *in,
+		 const struct lsh_string *in,
 		 int free);
 
 struct lsh_string *
 crypt_string_unpad(struct crypto_instance *c,
-		   struct lsh_string *in,
+		   const struct lsh_string *in,
 		   int free);
 
 #endif /* LSH_ABSTRACT_CRYPTO_H_INCLUDED */
