@@ -1,6 +1,6 @@
 /* client.c
  *
- * $Id: client.c,v 1.111 2001/03/20 17:22:23 nisse Exp $ */
+ * $Id: client.c,v 1.115 2001/04/10 15:47:02 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -104,16 +104,12 @@ do_accept_service(struct packet_handler *c,
 	      && (name == closure->service)))
       && parse_eod(&buffer))
     {
-      lsh_string_free(packet);
       connection->dispatch[SSH_MSG_SERVICE_ACCEPT] = &connection_fail_handler;
       
       COMMAND_RETURN(closure->c, connection);
     }
   else
-    {
-      lsh_string_free(packet);
-      PROTOCOL_ERROR(closure->e, "Invalid SSH_MSG_SERVICE_ACCEPT message");
-    }
+    PROTOCOL_ERROR(closure->e, "Invalid SSH_MSG_SERVICE_ACCEPT message");
 }
 
 struct packet_handler *
@@ -191,14 +187,6 @@ do_exit_status(struct channel_request *c,
       ALIST_SET(channel->request_types, ATOM_EXIT_STATUS, NULL);
       ALIST_SET(channel->request_types, ATOM_EXIT_SIGNAL, NULL);
 
-#if 0
-      /* Send EOF, if we haven't done that already. */
-      /* FIXME: Make this behaviour configurable, there may be some
-       * child process alive that we could talk to. */
-
-      channel_eof(channel);
-#endif
-      
       COMMAND_RETURN(s, NULL);
     }
   else
@@ -227,7 +215,7 @@ do_exit_signal(struct channel_request *c,
   UINT32 language_length;
   
   if (!info->want_reply
-      && parse_uint32(args, &signal)
+      && parse_atom(args, &signal)
       && parse_boolean(args, &core)
       && parse_string(args, &length, &msg)
       && parse_string(args, &language_length, &language)
@@ -238,11 +226,6 @@ do_exit_signal(struct channel_request *c,
 
       *closure->exit_status = 7;
 
-#if 0
-      signal = signal_network_to_local(signal);
-
-      werror("%ups", length, msg);
-#endif
       werror("Remote process was killed by signal: %ups %z\n",
 	     length, msg,
 	     core ? "(core dumped remotely)\n": "");
@@ -250,13 +233,6 @@ do_exit_signal(struct channel_request *c,
       ALIST_SET(channel->request_types, ATOM_EXIT_STATUS, NULL);
       ALIST_SET(channel->request_types, ATOM_EXIT_SIGNAL, NULL);
 
-#if 0
-      /* Send EOF, if we haven't done that already. */
-      /* FIXME: Make this behaviour configurable, there may be some
-       * child process alive that we could talk to. */
-
-      channel_eof(channel);
-#endif
       COMMAND_RETURN(s, NULL);
     }
   else
@@ -774,7 +750,7 @@ make_client_session(struct client_options *options)
   else
     {
       err = dup(STDERR_FILENO);
-      set_error_stream(STDERR_FILENO, 1);
+      set_error_nonblocking(STDERR_FILENO);
     }
 
   if (err < 0) 
@@ -789,11 +765,14 @@ make_client_session(struct client_options *options)
   options->stdin_file = options->stdout_file = options->stderr_file = NULL;
   
   return make_client_session_channel
-    (io_read(make_lsh_fd(options->backend, in, options->handler),
+    (io_read(make_lsh_fd(options->backend,
+			 in, "client stdin", options->handler),
 	     NULL, NULL),
-     io_write(make_lsh_fd(options->backend, out, options->handler),
+     io_write(make_lsh_fd(options->backend,
+			  out, "client stdout", options->handler),
 	      BLOCK_SIZE, NULL),
-     io_write(make_lsh_fd(options->backend, err, options->handler),
+     io_write(make_lsh_fd(options->backend,
+			  err, "client stderr", options->handler),
 	      BLOCK_SIZE, NULL),
      WINDOW_SIZE,
      options->exit_code);
