@@ -2,11 +2,11 @@
  *
  *
  *
- * $Id: client.h,v 1.36 2000/11/26 23:11:56 nisse Exp $ */
+ * $Id: client.h,v 1.39 2001/04/11 05:39:48 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
- * Copyright (C) 1998 Niels Mller
+ * Copyright (C) 1998, 1999, 2000, 2001 Niels Mller
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -62,6 +62,20 @@ do_request_service(struct command *s,
 { STATIC_COMMAND(do_request_service), service } 
 
 struct command *make_request_service(int service);
+
+/* GABA:
+   (class
+     (name escape_info)
+     (vars
+       (escape . UINT8)
+       ; Handlers, indexed by character.
+       (dispatch array (object lsh_callback) "0x100")))
+*/
+
+struct escape_info *make_escape_info(UINT8 escape);
+struct abstract_write *
+make_handle_escape(struct escape_info *info, struct abstract_write *next);
+
 struct channel_request *make_handle_exit_status(int *exit_code);
 struct channel_request *make_handle_exit_signal(int *exit_code);
 
@@ -84,6 +98,9 @@ make_client_session_channel(struct lsh_fd *in,
 struct command *
 make_exec_request(struct lsh_string *command);
 
+struct command *
+make_pty_request(struct interact *tty);
+
 /* GABA:
    (class
      (name client_options)
@@ -135,11 +152,6 @@ init_client_options(struct client_options *options,
 		    struct exception_handler *handler,
 		    int *exit_code);
 
-struct client_options *
-make_client_options(struct io_backend *backend,
-		    struct exception_handler *handler,
-		    int *exit_code);
-
 struct command *
 client_add_action(struct client_options *options,
 		  struct command *action);
