@@ -1,6 +1,6 @@
 /* client_pty.c
  *
- * $Id: client_pty.c,v 1.14 2000/11/15 21:54:50 nisse Exp $ */
+ * $Id: client_pty.c,v 1.17 2001/04/11 06:00:28 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -21,11 +21,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "client_pty.h"
+#include "client.h"
 
 #include "channel_commands.h"
 #include "format.h"
 #include "interact.h"
+#include "tty.h"
 #include "werror.h"
 #include "xalloc.h"
 
@@ -215,7 +216,7 @@ make_pty_request(struct interact *tty)
   req->super.super.call = do_channel_request_command;
   
   req->tty = tty;
-  req->term = term ? format_cstring(term) : ssh_format("");
+  req->term = term ? make_string(term) : ssh_format("");
 
   return &req->super.super;
 }
