@@ -1,6 +1,6 @@
 /* keyexchange.c
  *
- * $Id: keyexchange.c,v 1.75 2001/02/08 20:46:54 nisse Exp $ */
+ * $Id: keyexchange.c,v 1.77 2001/04/25 17:30:48 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -224,9 +224,11 @@ do_handle_kexinit(struct packet_handler *c,
 
   int mode = connection->flags & CONNECTION_MODE;
   struct kexinit *msg = parse_kexinit(packet);
-  
+
   int i;
 
+  verbose("Received KEXINIT message. Key exchange initated.\n");
+  
   if (connection->kex_state != KEX_STATE_INIT)
     {
       PROTOCOL_ERROR(connection->e, "Unexpected KEXINIT message.");
@@ -250,7 +252,7 @@ do_handle_kexinit(struct packet_handler *c,
 #if 0
   debug("do_handle_kexinit: Storing literal_kexinits[%i]\n", !mode);
 #endif
-  connection->literal_kexinits[!mode] = packet;
+  connection->literal_kexinits[!mode] = lsh_string_dup(packet);
   
   connection->kexinits[!mode] = msg;
   
@@ -586,6 +588,8 @@ do_handle_newkeys(struct packet_handler *c,
 
   simple_buffer_init(&buffer, packet->length, packet->data);
 
+  verbose("Received NEWKEYS. Key exchange finished.\n");
+  
   if (parse_uint8(&buffer, &msg_number)
       && (msg_number == SSH_MSG_NEWKEYS)
       && (parse_eod(&buffer)))
@@ -611,7 +615,6 @@ do_handle_newkeys(struct packet_handler *c,
     }
   else
     PROTOCOL_ERROR(connection->e, "Invalid NEWKEYS message");
-  lsh_string_free(packet);
 }
 
 struct packet_handler *
