@@ -2,7 +2,7 @@
  *
  * client main program
  *
- * $Id: lsh.c,v 1.133 2001/02/20 23:12:53 nisse Exp $ */
+ * $Id: lsh.c,v 1.140 2001/04/17 19:05:51 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -30,7 +30,6 @@
 #include "charset.h"
 #include "client.h"
 #include "client_keyexchange.h"
-#include "client_pty.h"
 #include "client_userauth.h"
 #include "compress.h"
 #include "connection_commands.h"
@@ -205,8 +204,8 @@ do_options2known_hosts(struct command *ignored UNUSED,
     s = options->known_hosts;
   else 
     {
-      tmp = ssh_cformat("%lz/.lsh/known_hosts", options->home);
-      s = tmp->data;
+      tmp = ssh_format("%lz/.lsh/known_hosts", options->home);
+      s = lsh_get_cstring(tmp);
     }
   
   f = io_read_file(options->super.backend, s, e);
@@ -253,8 +252,8 @@ do_options2identities(struct command *ignored UNUSED,
     s = options->identity;
   else 
     {
-      tmp = ssh_cformat("%lz/.lsh/identity", options->home);
-      s = tmp->data;
+      tmp = ssh_format("%lz/.lsh/identity", options->home);
+      s = lsh_get_cstring(tmp);
     }
   
   f = io_read_file(options->super.backend, s, e);
@@ -420,10 +419,12 @@ do_lsh_lookup(struct lookup_verifier *c,
     }
   else
     {
+      struct sexp *acl;
+      
       verbose("SPKI authorization failed.\n");
       if (!self->sloppy)
 	{
-	  werror("lsh: Server's hostkey is not trusted. Disconnecting.\n");
+	  werror("Server's hostkey is not trusted. Disconnecting.\n");
 	  return NULL;
 	}
       
@@ -444,21 +445,25 @@ do_lsh_lookup(struct lookup_verifier *c,
 			  self->host->ip, fingerprint), 0, 1))
 	    return NULL;
 	}
+
+      acl = sexp_l(2, sexp_a(ATOM_ACL),
+		   sexp_l(3, sexp_a(ATOM_ENTRY),
+			  subject->key,
+			  sexp_l(2, sexp_a(ATOM_TAG),
+				 self->access,
+				 -1),
+			  -1),
+		   -1);
+
+      /* Remember this key. We don't want to ask again for key re-exchange */
+      spki_add_acl(self->db, acl);
       
       /* Write an ACL to disk. */
       if (self->file)
 	{
 	  A_WRITE(self->file, ssh_format("\n; ACL for host %lS\n", self->host->ip));
 	  A_WRITE(self->file,
-		  sexp_format(sexp_l(2, sexp_a(ATOM_ACL),
-				     sexp_l(3, sexp_a(ATOM_ENTRY),
-					    subject->key,
-					    sexp_l(2, sexp_a(ATOM_TAG),
-						   self->access,
-						   -1),
-					    -1),
-				     -1),
-			      SEXP_TRANSPORT, 0));
+		  sexp_format(acl, SEXP_TRANSPORT, 0));
 	  A_WRITE(self->file, ssh_format("\n"));
 	}
     }
@@ -809,8 +814,8 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	  s = self->capture;
 	else if (self->sloppy)
 	  {
-	    tmp = ssh_cformat("%lz/.lsh/captured_keys", self->home);
-	    s = tmp->data;
+	    tmp = ssh_format("%lz/.lsh/captured_keys", self->home);
+	    s = lsh_get_cstring(tmp);
 	  }
 	if (s)
 	  {
@@ -899,26 +904,6 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
     CASE_FLAG(OPT_SRP, with_srp_keyexchange);
 
     CASE_FLAG(OPT_USERAUTH, with_userauth);
-
-#if 0
-    case 'L':
-      {
-	UINT32 listen_port;
-	struct address_info *target;
-
-	if (!client_parse_forward_arg(arg, &listen_port, &target))
-	  argp_error(state, "Invalid forward specification '%s'.", arg);
-
-	client_add_action(&self->super, make_forward_local_port
-			  (self->super.backend,
-			   make_address_info((self->super.with_remote_peers
-					      ? NULL
-					      : ssh_format("%lz", "127.0.0.1")),
-					     listen_port),
-			   target));
-	break;
-      }      
-#endif
       
     case 'R':
       {
@@ -979,21 +964,20 @@ do_lsh_default_handler(struct exception_handler *s,
       CAST_SUBTYPE(io_exception, exc, e);
       *self->status = EXIT_FAILURE;
       
-      werror("lsh: %z, (errno = %i)\n", e->msg, exc->error);
+      werror("%z, (errno = %i)\n", e->msg, exc->error);
     }
   else
     switch(e->type)
       {
       case EXC_RESOLVE:
       case EXC_USERAUTH:
-      case EXC_SERVICE:
       case EXC_SEXP_SYNTAX:
       case EXC_SPKI_TYPE:
       case EXC_GLOBAL_REQUEST:
       case EXC_CHANNEL_REQUEST:
       case EXC_CHANNEL_OPEN:
 
-	werror("lsh: %z\n", e->msg);
+	werror("%z\n", e->msg);
 	*self->status = EXIT_FAILURE;
 	break;
       default:
@@ -1072,13 +1056,17 @@ int main(int argc, char **argv)
    * or not anybody is still using it. */
   close(STDOUT_FILENO);
   if (open("/dev/null", O_WRONLY) != STDOUT_FILENO)
-    werror("lsh: Strange: Final redirect of stdout to /dev/null failed.\n");
+    werror("Strange: Final redirect of stdout to /dev/null failed.\n");
 #endif
   
   io_run(backend);
+
+  /* Close all files and other resources associated with the backend. */
+  io_final(backend);
   
+  gc_final();
+
   /* FIXME: Perhaps we have to reset the stdio file descriptors to
    * blocking mode? */
-  
   return lsh_exit_code;
 }
