@@ -2,7 +2,7 @@
  *
  * main server program.
  *
- * $Id: lshd.c,v 1.112.2.2 2001/05/11 21:48:01 nisse Exp $ */
+ * $Id: lshd.c,v 1.116 2001/05/15 21:04:32 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -187,6 +187,7 @@ do_exc_lshd_handler(struct exception_handler *s,
 {
   switch(e->type)
     {
+    case EXC_RESOLVE:
     case EXC_SEXP_SYNTAX:
     case EXC_SPKI_TYPE:
     case EXC_RANDOMNESS_LOW_ENTROPY:
@@ -709,7 +710,9 @@ int main(int argc, char **argv)
 
   options = make_lshd_options(backend);
   
+  trace("Parsing options...\n");
   argp_parse(&main_argp, argc, argv, 0, NULL, options);
+  trace("Parsing options...\n");  
 
   if (!options->corefile && !daemon_disable_core())
     {
@@ -751,10 +754,10 @@ int main(int argc, char **argv)
   /* NOTE: We have to do this *after* forking into the background,
    * because otherwise we won't be able to waitpid() on the background
    * process. */
-  
+
   /* Start background poll */
   RANDOM_POLL_BACKGROUND(options->random->poller);
-  
+	
   {
     /* Commands to be invoked on the connection */
     struct object_list *connection_hooks;
