@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: parse.c,v 1.31 2000/09/14 23:58:59 nisse Exp $ */
+ * $Id: parse.c,v 1.34 2001/04/25 17:28:32 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -249,11 +249,20 @@ parse_next_atom(struct simple_buffer *buffer, int *result)
 	return 0;
     }
 
-  /* No empty atoms. */
+  /* NOTE: ssh-2.0.13, server string "SSH-1.99-2.0.13
+   * (non-commercial)", sends USERAUTH_FAILURE messages with strings
+   * like "publickey,password,". It's not entirely clear to me if that
+   * is allowed for the spec, but it seems safe and straightforward to
+   * treat empty atoms as any other unknown atom. */
   if (!i)
-    return 0;
+    {
+      verbose("parse_next_atom: Received an empty atom.\n");
+      /* Treat empty atoms as unknown */
+      *result = 0;
+    }
+  else
+    *result = lookup_atom(i, HERE);
 
-  *result = lookup_atom(i, HERE);
   ADVANCE(i+1);  /* If the atom was terminated at the end of the
 		  * buffer, rather than by a comma, this points beyond
 		  * the end of the buffer */
@@ -306,6 +315,28 @@ parse_atom_list(struct simple_buffer *buffer, unsigned limit)
   return parse_atoms(&sub_buffer, limit);
 }
 
+void
+parse_rest(struct simple_buffer *buffer,
+	   UINT32 *length, const UINT8 **start)
+{
+  *length = LEFT;
+  *start = HERE;
+
+  ADVANCE(*length);
+}
+
+struct lsh_string *
+parse_rest_copy(struct simple_buffer *buffer)
+{
+  UINT32 length = LEFT;
+  struct lsh_string *s = ssh_format("%ls", length, HERE);
+
+  ADVANCE(length);
+  assert(!LEFT);
+
+  return s;
+}
+
 /* Returns success (i.e. 1) iff there is no data left */
 int
 parse_eod(struct simple_buffer *buffer)
