@@ -1,6 +1,6 @@
 /* proxy_agentforward.c
  *
- * $Id: proxy_agentforward.c,v 1.2 2000/03/26 20:38:33 nisse Exp $ */
+ * $Id: proxy_agentforward.c,v 1.4 2000/11/26 20:40:01 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -35,14 +35,11 @@
 static void
 do_proxy_open_auth_agent(struct channel_open *s UNUSED,
 			 struct ssh_connection *connection,
-			 UINT32 type,
-			 UINT32 send_window_size,
-			 UINT32 send_max_packet,
+			 struct channel_open_info *info,
 			 struct simple_buffer *args,
 			 struct command_continuation *c,
 			 struct exception_handler *e)
 {
-
   if (parse_eod(args))
     {
       struct gateway_channel *server
@@ -51,15 +48,14 @@ do_proxy_open_auth_agent(struct channel_open *s UNUSED,
       /* NOTE: The origin's rec_window_size and rec_max_packet becomes the target's
        * send_window_size and send_max_packet. */
       struct command *o
-	= make_gateway_channel_open_command(type, 
-					    send_window_size, send_max_packet,
+	= make_gateway_channel_open_command(info,
 					    ssh_format(""),
 					    NULL);
 
       werror("auth-agent open request\n");
       COMMAND_CALL(o,
 		   connection->chain,
-		   make_gateway_channel_open_continuation(c, server),
+		   make_gateway_channel_open_continuation(c, NULL, server),
 		   e);
 
     }
