@@ -4,7 +4,7 @@
  * processes and ports. Used to kill or release the resource in
  * question when the connection dies.
  *
- * $Id: resource.c,v 1.13 2001/02/18 22:33:15 nisse Exp $ */
+ * $Id: resource.c,v 1.17 2001/04/17 19:44:00 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -27,6 +27,7 @@
 
 #include "resource.h"
 
+#include "gc.h"
 #include "werror.h"
 #include "xalloc.h"
 
@@ -53,12 +54,23 @@ void do_free_resources(struct resource_node **q);
 
 
 /* Sanity check */
+
+/* NOTE: This happens normally during gc_final. Under all other
+ * circumstances, it's a serious error. */
 void
 dont_free_live_resource(int alive)
 {
   if (alive)
-    fatal("dont_free_live_resource: "
-	  "About to garbage collect a live resource!\n");
+    {
+#if DEBUG_ALLOC
+      if (gc_final_p)
+	verbose("dont_free_live_resource: "
+		"final collection of a live resource!\n");
+      else
+#endif
+	fatal("dont_free_live_resource: "
+	      "garbage collecting a live resource!\n");
+    }
 }
 
 /* For resources that are only marked as dead, and taken care of
@@ -141,7 +153,7 @@ do_remember_resource(struct resource_list *s,
   if (!self->super.super.alive)
     {
       werror("do_remember_resource: resource list is already dead.\n");
-      KILL(resource);
+      KILL_RESOURCE(resource);
       return;
     }
   
@@ -178,6 +190,7 @@ empty_resource_list(void)
   NEW(concrete_resource_list, self);
   resource_init(&self->super.super, do_kill_all);
 
+  trace("empty_resource_list: created %xi\n", self);
   self->super.remember = do_remember_resource;
   
   self->q = NULL;
