@@ -2,7 +2,7 @@
  *
  * Reads a sexp in given form from, and writes it in given form.
  *
- * $Id: sexp-conv.c,v 1.5 2000/11/15 17:35:27 nisse Exp $ */
+ * $Id: sexp-conv.c,v 1.7 2001/04/26 05:22:34 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -379,6 +379,7 @@ main_argp =
   
 
 #define SEXP_BUFFER_SIZE 1024
+#define MAX_SEXP_SIZE 100000
 
 int main(int argc, char **argv)
 {
@@ -395,18 +396,21 @@ int main(int argc, char **argv)
   {
     CAST_SUBTYPE(command, work,
 		 make_sexp_conv(
-		   make_read_sexp_command(options->input, !options->once),
+		   make_read_sexp_command(options->input,
+					  !options->once,
+					  MAX_SEXP_SIZE),
 		   options->select,
 		   options->transform,
 		   options->print,
 		   &(io_write(make_lsh_fd(backend,
-					 STDOUT_FILENO,
+					  STDOUT_FILENO,
+					  "stdout",
 					 e),
 			      SEXP_BUFFER_SIZE,
 			      NULL)
 		     ->write_buffer->super)));
 
-    struct lsh_fd *in = make_lsh_fd(backend, STDIN_FILENO, e);
+    struct lsh_fd *in = make_lsh_fd(backend, STDIN_FILENO, "stdin", e);
 
     /* Fixing the exception handler creates a circularity */
     e->parent = make_exc_finish_read_handler(in,
