@@ -1,6 +1,6 @@
 /* tcpforward.c
  *
- * $Id: tcpforward.c,v 1.59 2001/02/20 23:16:48 nisse Exp $
+ * $Id: tcpforward.c,v 1.61 2001/03/12 21:49:13 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -128,7 +128,7 @@ do_tcpip_receive(struct ssh_channel *c,
       lsh_string_free(data);
       break;
     default:
-      fatal("Internal error. do_tcpip_receive()");
+      fatal("Internal error. do_tcpip_receive");
     }
 }
 
@@ -146,18 +146,9 @@ do_tcpip_eof(struct ssh_channel *s)
 {
   CAST(tcpip_channel, self, s);
 
-  /* Tell the local peer that there's no more data.
-   * 1 is SHUT_WR.  */
-  if (shutdown (self->socket->fd, 1) < 0)
-    werror("do_tcpip_eof, shutdown() failed, (errno = %i): %z\n",
+  if (shutdown (self->socket->fd, SHUT_WR) < 0)
+    werror("do_tcpip_eof, shutdown failed, (errno = %i): %z\n",
 	   errno, STRERROR(errno));
-
-#if 0
-  /* Moved to channel.c:channel_eof_handler. */
-  if ( (s->flags & CHANNEL_SENT_EOF)
-       && (s->flags & CHANNEL_CLOSE_AT_EOF))
-    channel_close(s);
-#endif
 }
 
 /* NOTE: Adds the socket to the channel's resource list */
@@ -450,7 +441,7 @@ make_tcpip_forward_request_exc(struct ssh_connection *connection,
        ; The callback is invoked for each request, with the port as
        ; argument. If successful, it should return the fd object
        ; associated with the listening port. It need not remember the port;
-       ; the continuation installed by do_tcpip_forward_request()
+       ; the continuation installed by do_tcpip_forward_request
        ; takes care of that.
        (callback object command)))
 */
