@@ -1,6 +1,6 @@
 /* unix_random.c
  *
- * $Id: unix_random.c,v 1.5 2001/01/09 15:49:50 nisse Exp $
+ * $Id: unix_random.c,v 1.9 2001/04/25 17:31:51 nisse Exp $
  *
  * Randomness polling on unix, using ideas from Peter Gutmann's
  * cryptlib. */
@@ -126,7 +126,7 @@ make_unix_random_callback(struct unix_random *ctx)
 #define UNIX_RANDOM_POLL_SIZE 20
 
 /* This structure ought to fit in a pipe buffer (so that we can
- * waitpid() the process before reading its stdout). */
+ * waitpid the process before reading its stdout). */
 
 struct unix_random_poll_result
 {
@@ -269,7 +269,7 @@ static const struct unix_random_source random_sources[] =
   { "/usr/local/bin/wget", "-O - http://lavarand.sgi.com/block.html", 0, WLARGE(9) },
   { "/bin/cat", "/usr/spool/mqueue/syslog", 	0, WLARGE(9) },
 #endif /* 0 */
-  { NULL, NULL, 0, 0 }
+  { NULL, NULL, 0, 0, 0 }
 };
 
 #undef WSMALL
@@ -487,7 +487,7 @@ background_poll(struct hash_instance *hash)
       debug("unix_random.c: calling poll, nfds = %i\n", nfds);
       if (poll(fds, nfds, -1) < 0)
 	{
-	  werror("unix_random.c: background_poll poll() failed (errno = %i): %z\n",
+	  werror("unix_random.c: background_poll poll failed (errno = %i): %z\n",
 		 errno, STRERROR(errno));
 	  return count;
 	}
@@ -526,7 +526,7 @@ background_poll(struct hash_instance *hash)
 		{
 		  if (errno != EINTR)
 		    {
-		      werror("unix_random.c: background_poll read() failed (errno = %i): %z\n",
+		      werror("unix_random.c: background_poll read failed (errno = %i): %z\n",
 			     errno, STRERROR(errno));
 		      return count;
 		    }
@@ -562,15 +562,15 @@ background_poll(struct hash_instance *hash)
 		
 		  if (waitpid(state[j].pid, &status, 0) < 0)
 		    {
-		      werror("unix_random.c: background_poll waitpid() failed (errno = %i): %z\n",
+		      werror("unix_random.c: background_poll waitpid failed (errno = %i): %z\n",
 			     errno, STRERROR(errno));
 		      return count;
 		    }
 		  if (WIFEXITED(status))
 		    {
 		      if (WEXITSTATUS(status))
-			werror("unix_random.c: background_poll: %z exited unsuccessfully.\n",
-			       state[j].source->path);
+			debug("unix_random.c: background_poll: %z exited unsuccessfully.\n",
+			      state[j].source->path);
 		    }
 		  else if (WIFSIGNALED(status))
 		    {
@@ -619,8 +619,8 @@ start_background_poll(struct unix_random *self)
       self->pid = pid;
       self->status = POLL_RUNNING;
 
-      werror("unix_random.c: Started background poll. pid = %i.\n",
-	     pid);
+      verbose("unix_random.c: Started background poll. pid = %i.\n",
+	      pid);
       
       return;
 
@@ -690,7 +690,8 @@ wait_background_poll(struct unix_random *self)
   assert(self->status == POLL_RUNNING);
   trace("unix_random.c: wait_background_poll\n");
   self->status = POLL_FAILED;
-  
+
+  /* FIXME: Check error code. */
   if (waitpid(self->pid, &status, 0) == self->pid)
     {
       if (WIFEXITED(status) && !WEXITSTATUS(status))
@@ -793,7 +794,7 @@ do_unix_random_fast(struct random_poll *s, struct hash_instance *hash)
   {
     struct rusage rusage;
     if (getrusage(RUSAGE_SELF, &rusage) < 0)
-      fatal("do_unix_random_fast: getrusage() failed: (errno = %i) %z\n",
+      fatal("do_unix_random_fast: getrusage failed: (errno = %i) %z\n",
 	    errno, STRERROR(errno));
     
     HASH_OBJECT(hash, rusage);
@@ -813,7 +814,7 @@ do_unix_random_fast(struct random_poll *s, struct hash_instance *hash)
 
   {
     /* Fallback that is useful if nothing else works. Count the number
-     * of slow polls between time() ticks, and count one bit of
+     * of slow polls between time ticks, and count one bit of
      * entropy if we have more than 2 calls or more than two seconds
      * between calls. */
     
