@@ -1,6 +1,6 @@
 /* userauth.h
  *
- * $Id: userauth.h,v 1.25 2000/05/28 00:30:59 nisse Exp $
+ * $Id: userauth.h,v 1.29 2001/05/01 23:38:22 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -47,6 +47,7 @@ struct env_value;
        (reply string)))
 */
 
+/* FIXME: Perhaps it's better to use a const char * for the value? */
 struct env_value
 {
   const char *name;
@@ -57,6 +58,16 @@ struct exception *
 make_userauth_special_exception(struct lsh_string *reply,
 				const char *msg);
 
+/* GABA:
+   (class
+     (name lsh_process)
+     (super resource)
+     (vars
+       (signal method int int)))
+*/
+
+#define SIGNAL_PROCESS(p, s) ((p)->signal((p), (s)))
+
 /* GABA:
    (class
      (name lsh_user)
@@ -66,8 +77,11 @@ make_userauth_special_exception(struct lsh_string *reply,
        (name string)
        (uid . uid_t)
        
-       ; Verify a password
-       (verify_password method int "struct lsh_string *pw" "int free")
+       ; Verify a password. Consumes the password string.
+       (verify_password method void
+                        "struct lsh_string *pw"
+                        "struct command_continuation *c"
+			"struct exception_handler *e")
 
        ; Check if a file in the user's home directory exists.
        ; Used by the current publickey userauth method.
@@ -91,9 +105,11 @@ make_userauth_special_exception(struct lsh_string *reply,
        ; an object containing the stdin file objects and perhaps some
        ; other info.
 
+       ; This function also returns the pid.
+
        ; The tty argument is for utmp/wtmp logging
-       (fork_process method int "struct resource **child"
-                     "struct reap *reaper" "struct exit_callback *c"
+       (fork_process method int "struct lsh_process **child"
+                     "struct exit_callback *c"
                      "struct address_info * peer" "struct lsh_string *tty")
 
        ; This modifies the argv vector, in particular its first
@@ -101,17 +117,17 @@ make_userauth_special_exception(struct lsh_string *reply,
        ; (argv[0], NULL). 
 
        (exec_shell method void "int login"
-                   "char **argv"
+                   "const char **argv"
 		   "unsigned env_length"
 		   "const struct env_value *env")))
 */
 
-#define USER_VERIFY_PASSWORD(u, p, f) ((u)->verify_password((u), (p), (f)))
+#define USER_VERIFY_PASSWORD(u, p, c, e) ((u)->verify_password((u), (p), (c), (e)))
 #define USER_FILE_EXISTS(u, n, f) ((u)->file_exists((u), (n), (f)))
 #define USER_READ_FILE(u, n, s, x, e) ((u)->read_file((u), (n), (s), (x), (e)))
 #define USER_CHDIR_HOME(u) ((u)->chdir_home((u)))
-#define USER_FORK(u, c, r, e, p, t) \
-  ((u)->fork_process((u), (c), (r), (e), (p), (t)))
+#define USER_FORK(u, c, e, p, t) \
+  ((u)->fork_process((u), (c), (e), (p), (t)))
 #define USER_EXEC(u, m, a, l, e) ((u)->exec_shell((u), (m), (a), (l), (e)))
 
 #endif /* LSH_USERAUTH_H_INCLUDED */
