@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: write_buffer.h,v 1.19 2000/10/06 23:26:30 nisse Exp $ */
+ * $Id: write_buffer.h,v 1.20 2001/04/04 21:08:11 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -73,7 +73,7 @@
        (end . UINT32)))
 */
 
-struct write_buffer *write_buffer_alloc(UINT32 size);
+struct write_buffer *make_write_buffer(UINT32 size);
 int write_buffer_pre_write(struct write_buffer *buffer);
 void write_buffer_consume(struct write_buffer *buffer, UINT32 size);
 void write_buffer_close(struct write_buffer *buffer);
